const aws4 = require('aws4')
import { GET } from './http'

const API_GATEWAY_EXECUTE_API_SERVICE = 'execute-api'

export function sign ({
  host = '',
  path = '',
  awsConfig = {
    accessKeyId: '',
    region: '',
    secretAccessKey: '',
    sessionToken: ''
  }
} = {}) {
  const { accessKeyId, region, secretAccessKey, sessionToken } = awsConfig
  const signature = aws4.sign({
    host,
    path,
    service: API_GATEWAY_EXECUTE_API_SERVICE,
    region
  }, {
    accessKeyId,
    secretAccessKey,
    sessionToken
  })

  return signature
}

export function get ({
  host = '',
  stageName = '',
  stagePathPart = !stageName || stageName.startsWith('/') ? stageName : `/${stageName}`,
  path = '',
  awsConfig = {
    accessKeyId: '',
    region: '',
    secretAccessKey: '',
    sessionToken: ''
  },
  sign: _sign = sign,
  signature = _sign({
    awsConfig,
    host,
    path
  })
} = {}) {
  return GET(`https://${signature.host}${stagePathPart}${signature.path}`, {
    headers: signature.headers
  })
}

export default function makeApiGatewayClient ({
  host = '',
  stageName = '',
  awsConfig = {
    accessKeyId: '',
    region: '',
    secretAccessKey: '',
    sessionToken: ''
  },
  get: _get = get
} = {}) {
  return {
    get: ({ path }) => _get({ host, stageName, path, awsConfig })
  }
}
